# Summary of package
This package is my first objectorientedprogramming python pacakge that adds functionality of Gaussian and Binomial distribution calculations done with Python.

# files

Explination of files in the package

# Installation